@@ -1,8 +1,5 @@
-library(testthat)
+suppressMessages(library(dplyr))
 library(vdiffr)
-library(dplyr)
-
-context("ggside and date axis")
 
 set.seed(1234)
 
@@ -26,13 +23,15 @@ test_that("ggside work-around works",{
   p <- ggplot(df, aes(x = date, y = temperature)) +
     geom_line() +
     geom_point(aes(color = month_name))
-  p_yside <- p + geom_ysidehistogram()
+  p_yside <- p + geom_ysidehistogram(bins = 30)
   expect_error(ggplot_build(p_yside), regexp = "date_trans works with objects of class Date only")
   p_yside <- p_yside + scale_ysidex_continuous()
   expect_doppelganger("date_x_yside", p_yside)
-  p_xside <- p + geom_xsidehistogram() + scale_xsidey_continuous(trans = "log10")
+  p_xside <- p + geom_xsidehistogram(bins = 30) + scale_xsidey_continuous(trans = "log10")
   expect_doppelganger("date_x_xside", p_xside)
-  p_both <- p_yside + geom_xsidehistogram()
+  p_both <- p_yside + geom_xsidehistogram(bins = 30)
   expect_doppelganger("date_x_both", p_both)
+  p_wrap <- p_both + facet_wrap(~month) + ggside(collapse = "all")
+  expect_message(p_wrap, regexp = NA)
 
 })
